@@ -142,43 +142,62 @@ public class DriveServiceImpl implements DriveService {
     }
 
     @Override
-    public SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions, List<DirectoryVersion> clientVersions, boolean includeQuota) throws OXException {
+    public SyncResult<DirectoryVersion> syncFolder(DriveSession session, DirectoryVersion originalVersion, DirectoryVersion clientVersion) throws OXException {
+        /*
+         * get single path from client- or original version
+         */
+        String path;
+        if (null != originalVersion) {
+            path = originalVersion.getPath();
+            if (null != clientVersion && false == Strings.equalsNormalized(path, clientVersion.getPath())) {
+                throw DriveExceptionCodes.INVALID_DIRECTORYVERSION.create(clientVersion.getPath(), clientVersion.getChecksum());
+            }
+        } else if (null != clientVersion) {
+            path = clientVersion.getPath();
+        } else {
+            throw DriveExceptionCodes.INVALID_DIRECTORYVERSION.create("", "");
+        }
+        /*
+         * sync this directory
+         */
+        List<DirectoryVersion> originalVersions = null != originalVersion ? Collections.singletonList(originalVersion) : Collections.emptyList();
+        List<DirectoryVersion> clientVersions = null != clientVersion ? Collections.singletonList(clientVersion) : Collections.emptyList();
+        return syncFolders(session, originalVersions, clientVersions, (SyncSession syncSession) -> {
+            ServerDirectoryVersion serverVersion = syncSession.getServerDirectory(path);
+            return null == serverVersion ? Collections.emptyList() : Collections.singletonList(serverVersion);
+        });
+    }
+
+    @Override
+    public SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions, List<DirectoryVersion> clientVersions) throws OXException {
+        return syncFolders(session, originalVersions, clientVersions, (SyncSession syncSession) -> {
+            ServerSession serverSession = syncSession.getServerSession();
+            int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
+            return syncSession.getServerDirectories(maxDirectories);
+        });
+    }
+
+    private SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions, List<DirectoryVersion> clientVersions, VersionsProvider<ServerDirectoryVersion> serverVersionsProvider) throws OXException {
         ServerSession serverSession = session.getServerSession();
         /*
          * check (hard) version restrictions
          */
         if (session.getApiVersion() < DriveConfig.getInstance().getMinApiVersion(serverSession.getContextId(), serverSession.getUserId())) {
-            OXException error = DriveExceptionCodes.CLIENT_OUTDATED.create();
-            LOG.debug("Client synchronization aborted for {}", session, error);
-            List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
-            actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
-            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+            return getErrorResult(session, DriveExceptionCodes.CLIENT_OUTDATED.create(), true);
         }
         DriveClientVersion clientVersion = session.getClientVersion();
         if (null != clientVersion) {
             DriveClientVersion hardVersionLimit = DriveConfig.getInstance().getHardMinimumVersion(session.getClientType(), serverSession);
             if (0 > clientVersion.compareTo(hardVersionLimit)) {
-                OXException error = DriveExceptionCodes.CLIENT_VERSION_OUTDATED.create(clientVersion, hardVersionLimit);
-                LOG.debug("Client synchronization aborted for {}", session, error);
-                List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
-                actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
-                return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+                return getErrorResult(session, DriveExceptionCodes.CLIENT_VERSION_OUTDATED.create(clientVersion, hardVersionLimit), true);
             }
         }
         if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), session)) {
-            OXException error = DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID());
-            LOG.debug("Client synchronization aborted for {}", session, error);
-            List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
-            actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
-            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+            return getErrorResult(session, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
         }
         int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
         if (-1 != maxDirectories && null != clientVersions && maxDirectories < clientVersions.size()) {
-            OXException error = DriveExceptionCodes.TOO_MANY_DIRECTORIES.create(I(maxDirectories));
-            LOG.debug("Client synchronization aborted for {}", session, error);
-            List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
-            actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
-            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+            return getErrorResult(session, DriveExceptionCodes.TOO_MANY_DIRECTORIES.create(I(maxDirectories)), true);
         }
         /*
          * sync folders
@@ -190,20 +209,29 @@ public class DriveServiceImpl implements DriveService {
         int retryCount = 0;
         while (true) {
             /*
-             * get server directories
+             * init sync session & check root folder validity
              */
             final SyncSession driveSession = new SyncSession(session);
+            FileStorageFolder rootFolder;
             try {
-                serverVersions = driveSession.getServerDirectories(maxDirectories);
+                rootFolder = driveSession.getStorage().getFolder(DriveConstants.ROOT_PATH);
+            } catch (OXException e) {
+                if ("FLD-0003".equals(e.getErrorCode()) || "FLD-0008".equals(e.getErrorCode())) { // folder not found, folder not visible
+                    return getErrorResult(session, DriveExceptionCodes.NOT_ACCESSIBLE_DIRECTORY.create(session.getRootFolderID()), true);
+                }
+                throw e;
+            }
+            if (driveSession.getStorage().isExcludedSubfolder(rootFolder, DriveConstants.ROOT_PATH)) {
+                return getErrorResult(driveSession, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
+            }
+            /*
+             * get server directories
+             */
+            try {
+                serverVersions = serverVersionsProvider.getVersions(driveSession);
             } catch (OXException e) {
                 if ("DRV-0035".equals(e.getErrorCode())) {
-                    /*
-                     * Maximum number of synchronizable directories exceeded - stop synchronization
-                     */
-                    LOG.debug("Client synchronization aborted for {}", session, e);
-                    List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
-                    actionsForClient.add(new ErrorDirectoryAction(null, null, null, e, false, true));
-                    return new DefaultSyncResult<DirectoryVersion>(actionsForClient, e.getLogMessage());
+                    return getErrorResult(driveSession, e, true); // Too many directories
                 }
                 if (tryAgain(driveSession, e, retryCount, "Error collecting server directories")) {
                     retryCount++;
@@ -261,10 +289,7 @@ public class DriveServiceImpl implements DriveService {
                     actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, false));
                 }
             }
-            DriveQuota quota = null;
-            if (includeQuota) {
-                quota = getQuota(session);
-            }
+            DriveQuota quota = session.isIncludeQuota() ? getQuota(session) : null;
             /*
              * return actions for client
              */
@@ -272,43 +297,52 @@ public class DriveServiceImpl implements DriveService {
                 driveSession.trace("syncFolders with " + syncResult.length() + " resulting action(s) completed after "
                     + (System.currentTimeMillis() - start) + "ms.");
             }
-            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota);
+            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID());
+            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot);
         }
     }
 
     @Override
-    public SyncResult<FileVersion> syncFiles(DriveSession session, final String path, List<FileVersion> originalVersions, List<FileVersion> clientVersions, boolean includeQuota) throws OXException {
+    public SyncResult<FileVersion> syncFiles(DriveSession session, final String path, List<FileVersion> originalVersions, List<FileVersion> clientVersions) throws OXException {
         long start = System.currentTimeMillis();
         DriveVersionValidator.validateFileVersions(originalVersions);
         DriveVersionValidator.validateFileVersions(clientVersions);
         ServerSession serverSession = session.getServerSession();
         int maxFilesPerDirectory = DriveConfig.getInstance().getMaxFilesPerDirectory(serverSession.getContextId(), serverSession.getUserId());
         if (-1 != maxFilesPerDirectory && null != clientVersions && maxFilesPerDirectory < clientVersions.size()) {
-            OXException error = DriveExceptionCodes.TOO_MANY_FILES.create(I(maxFilesPerDirectory), path);
-            LOG.debug("Client synchronization aborted for {}", session, error);
-            List<AbstractAction<FileVersion>> actionsForClient = new ArrayList<AbstractAction<FileVersion>>(1);
-            actionsForClient.add(new ErrorFileAction(null, null, null, path, error, false, true));
-            return new DefaultSyncResult<FileVersion>(actionsForClient, error.getLogMessage());
+            return getErrorResult(session, path, DriveExceptionCodes.TOO_MANY_FILES.create(I(maxFilesPerDirectory), path), true);
+        }
+        if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), session)) {
+            return getErrorResult(session, path, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
         }
         int retryCount = 0;
         while (true) {
             /*
-             * get server files
+             * init sync session & check root folder validity
              */
             final SyncSession driveSession = new SyncSession(session);
+            FileStorageFolder rootFolder;
+            try {
+                rootFolder = driveSession.getStorage().getFolder(DriveConstants.ROOT_PATH);
+            } catch (OXException e) {
+                if ("FLD-0003".equals(e.getErrorCode()) || "FLD-0008".equals(e.getErrorCode())) { // folder not found, folder not visible
+                    return getErrorResult(session, path, DriveExceptionCodes.NOT_ACCESSIBLE_DIRECTORY.create(session.getRootFolderID()), true);
+                }
+                throw e;
+            }
+            if (driveSession.getStorage().isExcludedSubfolder(rootFolder, DriveConstants.ROOT_PATH)) {
+                return getErrorResult(driveSession, path, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
+            }
+            /*
+             * get server files in path
+             */
             driveSession.getStorage().createFolder(path);
             List<ServerFileVersion> serverVersions;
             try {
                 serverVersions = driveSession.getServerFiles(path, maxFilesPerDirectory);
             } catch (OXException e) {
                 if ("DRV-0036".equals(e.getErrorCode())) {
-                    /*
-                     * Maximum number of synchronizable files exceeded - stop synchronization
-                     */
-                    LOG.debug("Client synchronization aborted for {}", session, e);
-                    List<AbstractAction<FileVersion>> actionsForClient = new ArrayList<AbstractAction<FileVersion>>(1);
-                    actionsForClient.add(new ErrorFileAction(null, null, null, path, e, false, true));
-                    return new DefaultSyncResult<FileVersion>(actionsForClient, e.getLogMessage());
+                    return getErrorResult(driveSession, path, e, true); // too many files
                 }
                 if (tryAgain(driveSession, e, retryCount, "Error collecting server files")) {
                     retryCount++;
@@ -340,10 +374,7 @@ public class DriveServiceImpl implements DriveService {
                 }
                 throw e;
             }
-            DriveQuota quota = null;
-            if (includeQuota) {
-                quota = getQuota(session);
-            }
+            DriveQuota quota = session.isIncludeQuota() ? getQuota(session) : null;
             /*
              * return actions for client
              */
@@ -351,7 +382,8 @@ public class DriveServiceImpl implements DriveService {
                 driveSession.trace("syncFiles with " + syncResult.length() + " resulting action(s) completed after "
                     + (System.currentTimeMillis() - start) + "ms.");
             }
-            return new DefaultSyncResult<FileVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota);
+            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID());
+            return new DefaultSyncResult<FileVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot);
         }
     }
 
@@ -460,7 +492,8 @@ public class DriveServiceImpl implements DriveService {
          */
         DriveSettings settings = new DriveSettings();
         ServerSession serverSession = session.getServerSession();
-        Quota[] quota = syncSession.getStorage().getQuota();
+        DriveStorage storage = syncSession.getStorage();
+        Quota[] quota = storage.getQuota();
         LOG.debug("Got quota for root folder '{}': {}", session.getRootFolderID(), quota);
         settings.setQuota(new DriveQuotaImpl(quota, syncSession.getLinkGenerator().getQuotaLink()));
         settings.setHelpLink(syncSession.getLinkGenerator().getHelpLink());
@@ -468,13 +501,14 @@ public class DriveServiceImpl implements DriveService {
         settings.setMinApiVersion(String.valueOf(DriveConfig.getInstance().getMinApiVersion(serverSession.getContextId(), serverSession.getUserId())));
         settings.setSupportedApiVersion(String.valueOf(DriveConstants.SUPPORTED_API_VERSION));
         settings.setMinUploadChunk(Long.valueOf(syncSession.getOptimisticSaveThreshold()));
-        settings.setHasTrashFolder(syncSession.getStorage().hasTrashFolder());
+        settings.setHasTrashFolder(storage.hasTrashFolder());
+        settings.setPathToRoot(storage.getInternalPath(session.getRootFolderID()));
         /*
          * add any localized folder names (up to a certain depth after which no localized names are expected anymore)
          */
         Map<String, String> localizedFolders = new HashMap<String, String>();
         int maxDirectories = DriveConfig.getInstance().getMaxDirectories(serverSession.getContextId(), serverSession.getUserId());
-        Map<String, FileStorageFolder> folders = syncSession.getStorage().getFolders(maxDirectories, 2);
+        Map<String, FileStorageFolder> folders = storage.getFolders(maxDirectories, 2);
         for (Map.Entry<String, FileStorageFolder> entry : folders.entrySet()) {
             String localizedName = entry.getValue().getLocalizedName(session.getLocale());
             if (Strings.isNotEmpty(localizedName) && false == localizedName.equals(entry.getValue().getName())) {
@@ -682,4 +716,80 @@ public class DriveServiceImpl implements DriveService {
         return DriveUtilityImpl.getInstance();
     }
 
+    /**
+     * Wraps an exception into an appropriate <code>error</code> action for the client, optionally setting the <code>stop</code> flag.
+     * <p/>
+     * An appropriate debug error message is logged implicitly, and the sync result is traced if enabled.
+     *
+     * @param session The sync session
+     * @param path The path to the currently synchronized directory
+     * @param error The error to take over for the action
+     * @param stop <code>true</code> to set the <code>stop</code>-flag in the error action, <code>false</code>, otherwise
+     * @return A sync result holding the error action
+     */
+    private static DefaultSyncResult<FileVersion> getErrorResult(SyncSession session, String path, OXException error, boolean stop) {
+        LOG.debug("Client synchronization aborted for {}", session, error);
+        IntermediateSyncResult<FileVersion> syncResult = new IntermediateSyncResult<FileVersion>();
+        syncResult.addActionForClient(new ErrorFileAction(null, null, null, path, error, false, stop));
+        if (session.isTraceEnabled()) {
+            session.trace(syncResult);
+        }
+        return new DefaultSyncResult<FileVersion>(syncResult.getActionsForClient(), session.getDiagnosticsLog());
+    }
+
+    /**
+     * Wraps an exception into an appropriate <code>error</code> action for the client, optionally setting the <code>stop</code> flag.
+     * <p/>
+     * An appropriate debug error message is logged implicitly, and the sync result is traced if enabled.
+     *
+     * @param session The sync session
+     * @param error The error to take over for the action
+     * @param stop <code>true</code> to set the <code>stop</code>-flag in the error action, <code>false</code>, otherwise
+     * @return A sync result holding the error action
+     */
+    private static DefaultSyncResult<DirectoryVersion> getErrorResult(SyncSession session, OXException error, boolean stop) {
+        LOG.debug("Client synchronization aborted for {}", session, error);
+        IntermediateSyncResult<DirectoryVersion> syncResult = new IntermediateSyncResult<DirectoryVersion>();
+        syncResult.addActionForClient(new ErrorDirectoryAction(null, null, null, error, false, stop));
+        if (session.isTraceEnabled()) {
+            session.trace(syncResult);
+        }
+        return new DefaultSyncResult<DirectoryVersion>(syncResult.getActionsForClient(), session.getDiagnosticsLog());
+    }
+
+    /**
+     * Wraps an exception into an appropriate <code>error</code> action for the client, optionally setting the <code>stop</code> flag.
+     * <p/>
+     * An appropriate debug error message is logged implicitly.
+     *
+     * @param session The drive session
+     * @param path The path to the currently synchronized directory
+     * @param error The error to take over for the action
+     * @param stop <code>true</code> to set the <code>stop</code>-flag in the error action, <code>false</code>, otherwise
+     * @return A sync result holding the error action
+     */
+    private static DefaultSyncResult<FileVersion> getErrorResult(DriveSession session, String path, OXException error, boolean stop) {
+        LOG.debug("Client synchronization aborted for {}", session, error);
+        List<AbstractAction<FileVersion>> actionsForClient = new ArrayList<AbstractAction<FileVersion>>(1);
+        actionsForClient.add(new ErrorFileAction(null, null, null, path, error, false, stop));
+        return new DefaultSyncResult<FileVersion>(actionsForClient, error.getLogMessage());
+    }
+
+    /**
+     * Wraps an exception into an appropriate <code>error</code> action for the client, optionally setting the <code>stop</code> flag.
+     * <p/>
+     * An appropriate debug error message is logged implicitly.
+     *
+     * @param session The drive session
+     * @param error The error to take over for the action
+     * @param stop <code>true</code> to set the <code>stop</code>-flag in the error action, <code>false</code>, otherwise
+     * @return A sync result holding the error action
+     */
+    private static DefaultSyncResult<DirectoryVersion> getErrorResult(DriveSession session, OXException error, boolean stop) {
+        LOG.debug("Client synchronization aborted for {}", session, error);
+        List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
+        actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
+        return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+    }
+
 }
