@@ -53,6 +53,7 @@ import java.util.List;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.events.DriveEvent;
+import com.openexchange.drive.events.subscribe.SubscriptionMode;
 import com.openexchange.exception.OXException;
 
 /**
@@ -102,4 +103,11 @@ public interface LongPollingListener {
      */
     List<String> getRootFolderIDs();
 
+    /**
+     * Gets the subscription mode of the listener.
+     * 
+     * @return The subscription mode
+     */
+    SubscriptionMode getSubscriptionMode();
+
 }
