@@ -50,7 +50,6 @@
 package com.openexchange.drive.json.action;
 
 import java.util.List;
-import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -113,21 +112,19 @@ public class SyncFoldersAction extends AbstractDriveAction {
          */
         try {
             DriveService driveService = Services.getService(DriveService.class, true);
-            boolean includeQuota = requestData.containsParameter("quota") ? requestData.getParameter("quota", Boolean.class).booleanValue() : false;
-            SyncResult<DirectoryVersion> syncResult = driveService.syncFolders(session, originalVersions, clientVersions, includeQuota);
-            if (null != session.isDiagnostics() || includeQuota) {
-                JSONObject jsonObject = new JSONObject();
+            SyncResult<DirectoryVersion> syncResult = driveService.syncFolders(session, originalVersions, clientVersions);
+            JSONObject jsonObject = new JSONObject();
+            jsonObject.put("actions", JsonDriveAction.serializeActions(syncResult.getActionsForClient(), session.getLocale()));
+            jsonObject.put("pathToRoot", syncResult.getPathToRoot());
+            if (null != session.isDiagnostics() || session.isIncludeQuota()) {
                 if (null != session.isDiagnostics()) { 
                     jsonObject.put("diagnostics", syncResult.getDiagnostics());
                 }
-                if (includeQuota) {
-                    JSONArray quotaAsJSON = DriveJSONUtils.serializeQuota(syncResult.getQuota());
-                    jsonObject.put("quota", quotaAsJSON);
+                if (session.isIncludeQuota()) {
+                    jsonObject.put("quota", DriveJSONUtils.serializeQuota(syncResult.getQuota()));
                 }
-                jsonObject.put("actions", JsonDriveAction.serializeActions(syncResult.getActionsForClient(), session.getLocale()));
-                return new AJAXRequestResult(jsonObject, "json");
             }
-            return new AJAXRequestResult(JsonDriveAction.serializeActions(syncResult.getActionsForClient(), session.getLocale()), "json");
+            return new AJAXRequestResult(jsonObject, "json");
         } catch (OXException e) {
             if ("DRV".equals(e.getPrefix())) {
                 LOG.debug("Error performing syncFolders request", e);
